---
name: Bug report
about: Let us know about a bug
---

<!-- Please reserve GitHub issues for bug reports and feature requests.

For questions, the best place to get answers is on our [Discord channel](http://skale.chat), where questions will get more visibility from experienced users than the issue tracker.

-->

-   SKALE library version: x.x.x
-   Python: 3.\*
-   OS: osx/linux/win
-   `pip freeze` output


    <!-- put the output from running pip freeze here -->

### Expected behavior

<!-- What should have happened? -->

### Actual behavior

<!-- What actually happened? -->

### Steps to reproduce

1\.
2\.
3\.

### Debug output

<!-- Provide a link to a GitHub Gist containing the complete debug output. The debut output should be very long. Do NOT paste the debut output in the issue, just paste the link to the Gist. -->

### References

<!-- Are there any other GitHub issues (open or closed) that should be linked here? -->

<!-- For example: -->

<!-- - GH-1234 -->

<!-- - ... -->

### How can it be fixed

<!-- Fill this section in if you know how this could or should be fixed. -->
